@@ -53,7 +53,9 @@ for model in dalle_image_generation_models:
 ModelParserRegistry.register_model_parser(
     DefaultAnyscaleEndpointParser("AnyscaleEndpoint")
 )
-ModelParserRegistry.register_model_parser(GeminiModelParser("gemini-pro"), ["gemini-pro"])
+ModelParserRegistry.register_model_parser(
+    GeminiModelParser("gemini-pro"), ["gemini-pro"]
+)
 ModelParserRegistry.register_model_parser(ClaudeBedrockModelParser())
 ModelParserRegistry.register_model_parser(HuggingFaceTextGenerationParser())
 for model in gpt_models_extra:
@@ -61,6 +63,7 @@ for model in gpt_models_extra:
 ModelParserRegistry.register_model_parser(PaLMChatParser())
 ModelParserRegistry.register_model_parser(PaLMTextParser())
 
+
 class AIConfigRuntime(AIConfig):
     # A mapping of model names to their respective parsers
 
@@ -116,14 +119,37 @@ class AIConfigRuntime(AIConfig):
             else:
                 data = file.read()
 
-        # load the file as bytes and let pydantic handle the parsing
-        # validated_data =  AIConfig.model_validate_json(file.read())
-        aiconfigruntime = cls.model_validate_json(data)
-        update_model_parser_registry_with_config_runtime(aiconfigruntime)
-
+        config_runtime = cls.load_json(data)
         # set the file path. This is used when saving the config
-        aiconfigruntime.file_path = config_filepath
-        return aiconfigruntime
+        config_runtime.file_path = config_filepath
+        return config_runtime
+
+    @classmethod
+    def load_json(cls, config_json: str) -> "AIConfigRuntime":
+        """
+        Constructs AIConfigRuntime from provided JSON and returns it.
+
+        Args:
+            config_json (str): The JSON representing the AIConfig.
+        """
+
+        config_runtime = cls.model_validate_json(config_json)
+        update_model_parser_registry_with_config_runtime(config_runtime)
+
+        return config_runtime
+
+    @classmethod
+    def load_yaml(cls, config_yaml: str) -> "AIConfigRuntime":
+        """
+        Constructs AIConfigRuntime from provided YAML and returns it.
+
+        Args:
+            config_yaml (str): The YAML representing the AIConfig.
+        """
+
+        yaml_data = yaml.safe_load(config_yaml)
+        config_json = json.dumps(yaml_data)
+        return cls.load_json(config_json)
 
     @classmethod
     def load_from_workbook(cls, workbook_id: str) -> "AIConfigRuntime":
@@ -429,17 +455,6 @@ class AIConfigRuntime(AIConfig):
             config_filepath (str, optional): The file path to the JSON or YAML configuration file.
                 Defaults to "aiconfig.json" or "aiconfig.yaml", depending on the mode.
         """
-        # Decide if we want to serialize as YAML or JSON
-
-        # AIConfig json should only contain the core data fields. These are auxiliary fields that should not be persisted
-        exclude_options = {
-            "prompt_index": True,
-            "file_path": True,
-            "callback_manager": True,
-        }
-
-        if not include_outputs:
-            exclude_options["prompts"] = {"__all__": {"outputs"}}
 
         default_filepath = (
             "aiconfig.yaml" if mode == "yaml" else "aiconfig.json"
@@ -455,30 +470,54 @@ class AIConfigRuntime(AIConfig):
                 # Default to JSON
                 mode = "json"
 
+        config_string = self.to_string(include_outputs, mode)
+
         with open(config_filepath, "w") as file:
-            # Serialize the AIConfig to JSON
-            json_data = self.model_dump(
-                mode="json",
-                exclude=exclude_options,
-                exclude_none=True,
+            file.write(config_string)
+
+    def to_string(
+        self,
+        include_outputs: bool = True,
+        mode: Literal["json", "yaml"] = "json",
+    ) -> str:
+        """
+        Returns the well-formatted string representing the AIConfig object.
+        Note that this method will return the string that would be saved as a .aiconfig file using the save() method.
+        To get the raw string representation of the AIConfig object, use the __str__() method.
+        """
+        # AIConfig json should only contain the core data fields. These are auxiliary fields that should not be persisted
+        exclude_options = {
+            "prompt_index": True,
+            "file_path": True,
+            "callback_manager": True,
+        }
+
+        if not include_outputs:
+            exclude_options["prompts"] = {"__all__": {"outputs"}}
+
+        # Serialize the AIConfig to JSON
+        json_data = self.model_dump(
+            mode="json",
+            exclude=exclude_options,
+            exclude_none=True,
+        )
+
+        if json_data.get("$schema", None) is None:
+            # Set the schema if it is not set
+            json_data["$schema"] = "https://json.schemastore.org/aiconfig-1.0"
+
+        if mode == "yaml":
+            # Save AIConfig JSON as YAML string
+            return yaml.dump(
+                json_data,
+                indent=2,
+            )
+        else:
+            # Save AIConfig as JSON string, with the schema specified
+            return json.dumps(
+                json_data,
+                indent=2,
             )
-            if mode == "yaml":
-                # Save AIConfig JSON as YAML to the file
-                yaml.dump(
-                    json_data,
-                    file,
-                    indent=2,
-                )
-            else:
-                # Save AIConfig as JSON to the file, with the schema specified
-                json_data[
-                    "$schema"
-                ] = "https://json.schemastore.org/aiconfig-1.0"
-                json.dump(
-                    json_data,
-                    file,
-                    indent=2,
-                )
 
     def get_output_text(
         self, prompt: str | Prompt, output: Optional[dict] = None
